# Library Comparison

This page provides a comparison between yaucl and alternative configuration libraries to help you choose the right tool for your needs.

## Comparison Table

| Feature                   | yaucl              | pydantic-settings           | confuse            | dynaconf              | python-decouple       |
|---------------------------|--------------------|-----------------------------|--------------------|-----------------------|-----------------------|
| **Primary Focus**         | User configuration | General settings management | User configuration | Deployed applications | Environment variables |
| **Type Hints**            | Full support       | Full support                | Limited            | Partial               | Limited               |
| **Default Config Format** | TOML               | Multiple formats            | YAML               | Multiple formats      | INI, .env             |
| **Config File Location**  | OS based           | Configurable                | OS based           | Configurable          | Configurable          |
| **Validation**            | Type-based         | Extensive validation        | Template-based     | Type-based            | Basic                 |
| **Learning Curve**        | Low                | Medium                      | Medium             | Medium-High           | Low                   |
